@@ -23,6 +23,8 @@ def get_transcription_results(transcripiton_id:str, all_details: bool=False) ->
   status = full_details.get('status')
   while status not in ['completed', 'error']:
     time.sleep(5) # sleep for secs
+    full_details = get_status_of_transcription(transcripiton_id)
+    status = full_details.get('status')
   
   if all_details:
     return full_details  
